from datetime import datetime

class Release():
    releaseUrl: str
    releaseNotes: str
    version: str
    publishDate: str
    
    def publishDateAsDate(self) -> datetime:
        return datetime.strptime(self.publishDate, "%Y-%m-%dT%H:%M:%SZ") # 2021-08-31T05:16:04Z

    def publishedSince(self, date: datetime) -> bool:
        return self.publishDateAsDate() > date 

    def to_json(self):
        return self.__dict__  




from datetime import datetime
from .models import Release, Notification
import requests

class GitHubService:
    def __init__(self, token: str):
        self.base_api_url = f'https://api.github.com'
        self.token = token

    def latestRelease(self, repo: str) -> Release:
        r = requests.get(f'{self.base_api_url}/repos/{repo}/releases/latest', headers={'Authorization': self.token})
        results = r.json()
        if(results is None):
            return None
        output = Release()
        output.releaseUrl = results['html_url']
        output.releaseNotes = results['body']
        output.version = results['tag_name']
        output.publishDate = results['published_at']
        return output

    def generateNotification(self, repo: str, sinceDate: datetime = None) -> Notification:
        r = requests.get(f'{self.base_api_url}/repos/{repo}', headers={'Authorization': self.token})
        results = r.json()
        output = Notification()
        output.name = repo
        if('html_url' not in results):
            print(results) # Debug - were we rate limited?
            return output
        output.repoInfo = results['html_url']
        output.releaseInfo = self.latestRelease(repo)
        # If we have release data and a sinceDate then we compare the dates to filter output.
        if(sinceDate is not None and output.releaseInfo is not None and output.releaseInfo.publishedSince(datetime.strptime(sinceDate, "%Y-%m-%d")) is not True):
            return None

        return output



from setuptools import setup, find_packages

__version__ = '0.1.1'

with open('README.md', 'r', encoding='utf-8') as readme:
    long_description = readme.read()

setup(
    name='techharper',
    author="Alex Elia",
    author_email="alex.elia42+pip@gmail.com",
    packages=find_packages(),
    version=__version__,
    description='Tool to fetch the latest updates for technologies',
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=[
        'requests==2.25.1',
    ],
    url='https://github.com/BoredTweak/techharper',
    python_requires='>=3.7',
    zip_safe=False,
    license='GPL-3',
    classifiers=[
        "Programming Language :: Python :: 3",
    ]
)